@@ -2,7 +2,7 @@ from django import forms
 
 
 class SetRequiredMixin:
-    """ mixin class that sets fields as form fields as required or not_required based on the form Meta class parameters
+    """ mixin class that sets form fields as required or not_required based on the form Meta class parameters
      'required' and/or 'not_required'. Both parameters are a list of fields in the form. The 'required' parameter takes
      precedence over 'not_required' parameter if fields are listed in both lists.
 
